@@ -2,6 +2,51 @@
  * Simple Creation API, mainly designed for use in the ECMAScript console.
  */
 
+/**
+ * Sets the current color for newly added entities
+ * \ingroup ecma_simple
+ *
+ * \code
+ * setCurrentColor(new RColor(255, 255, 255))
+ * setCurrentColor(new RColor("white"))
+ * setCurrentColor(255, 255, 255)
+ * \endcode
+ */
+function setCurrentColor(color) {
+    var di = getTransactionDocumentInterface();
+    if (isNull(di)) {
+        di = getTransactionDocument();
+    }
+    if (isNull(di)) {
+        qWarning("no document interface or document");
+        return;
+    }
+
+    // r, g, b:
+    if (arguments.length===3) {
+        setCurrentColor(new RColor(arguments[0], arguments[1], arguments[2]));
+        return;
+    }
+
+    di.setCurrentColor(color);
+}
+
+/**
+ * Checks if the given layer exists.
+ * \ingroup ecma_simple
+ *
+ * \code
+ * hasLayer("MyLayer1")
+ * \endcode
+ */
+function hasLayer(name) {
+    var doc = getTransactionDocument();
+    if (isNull(doc)) {
+        return false;
+    }
+    return doc.hasLayer(name);
+}
+
 /**
  * Adds a layer to the drawing.
  * \ingroup ecma_simple
@@ -41,6 +86,20 @@ function addLayer(name, colorName, linetypeName, lineWeight) {
     return addObject(layer);
 }
 
+/**
+ * Sets the current layer to the given layer.
+ * \ingroup ecma_simple
+ *
+ * \param layerName Layer name or ID.
+ */
+function setCurrentLayer(layerName) {
+    var di = getTransactionDocumentInterface();
+    if (isNull(di)) {
+        return false;
+    }
+    di.setCurrentLayer(layerName);
+}
+
 /**
  * Adds a point to the drawing.
  * \ingroup ecma_simple
@@ -88,6 +147,33 @@ function addLine(startPoint, endPoint) {
     return addShape(new RLine(startPoint, endPoint));
 }
 
+/**
+ * Adds an infinite line to the drawing.
+ * The two vectors are the base point and the direction vector
+ * (point relative to base point)
+ * \ingroup ecma_simple
+ *
+ * \code
+ * addXLine(x1,y1, dx,dy)
+ * addXLine([x1,y1], [dx,dy])
+ * addXLine(new RVector(x1,y1), new RVector(dx,dy))
+ * \endcode
+ */
+function addXLine(startPoint, directionVector) {
+    if (arguments.length===4) {
+        return addXLine(new RVector(arguments[0], arguments[1]), new RVector(arguments[2], arguments[3]));
+    }
+
+    if (isArray(startPoint)) {
+        startPoint = new RVector(startPoint);
+    }
+    if (isArray(directionVector)) {
+        directionVector = new RVector(directionVector);
+    }
+
+    return addShape(new RXLine(startPoint, directionVector));
+}
+
 /**
  * Adds an arc to the drawing.
  * \ingroup ecma_simple
@@ -187,7 +273,7 @@ function addPolyline(points, closed, relative) {
                 rel = points[i][2];
             }
         }
-        else {
+        else if (isArray(points[i])) {
             v0 = new RVector(points[i][0], points[i][1]);
             if (!isNull(points[i][2])) {
                 b = points[i][2];
@@ -196,6 +282,17 @@ function addPolyline(points, closed, relative) {
                 rel = points[i][3];
             }
         }
+        else if (isNumber(points[i].x) && isNumber(points[i].y)){
+            if (isNumber(points[i].z)) {
+                v0 = new RVector(points[i].x, points[i].y, points[i].z);
+            }
+            else {
+                v0 = new RVector(points[i].x, points[i].y);
+            }
+            if (isNumber(points[i].b)) {
+                b = points[i].b;
+            }
+        }
 
         // relative or absolute vertex position:
         if (relative) {
@@ -220,7 +317,7 @@ function addPolyline(points, closed, relative) {
  *
  * \code
  * addSpline([[x1,y1],[x2,y2],[x3,y3]], false)
- * addSpline([new RVector(x1,y1)],new RVector(x2,y2),new RVector(x3,y3)], false)
+ * addSpline([new RVector(x1,y1),new RVector(x2,y2),new RVector(x3,y3)], false)
  * \endcode
  */
 function addSpline(points, closed) {
@@ -264,6 +361,10 @@ function addSimpleText(text, position, height, angle, font, vAlign, hAlign, bold
     if (arguments.length===10) {
         return addSimpleText(arguments[0], new RVector(arguments[1], arguments[2]), arguments[3], arguments[4], arguments[5], arguments[6], arguments[7], arguments[8], arguments[9]);
     }
+    if (arguments.length===3 && isNumber(position)) {
+        // addSimpleText("text", x, y)
+        return addSimpleText(arguments[0], new RVector(arguments[1], arguments[2]));
+    }
 
     var doc = getTransactionDocument();
     if (isNull(doc)) {
@@ -324,14 +425,32 @@ function addShapes(shapes) {
  *
  * \return The added entity. The entity does not yet have a valid ID if it was added within a
  * transaction.
+ *
+ * \code
+ * addShape(shape)
+ * addShape(shape, new RColor(255,0,0), "CONTINUOUS", 0.05)
+ * \endcode
  */
-function addShape(shape) {
+function addShape(shape, color, linetype, lineweight) {
     var doc = getTransactionDocument();
     if (isNull(doc)) {
         return undefined;
     }
 
     var entity = shapeToEntity(doc, shape);
+    if (!isNull(color)) {
+        entity.setColor(color);
+    }
+    if (isNumber(linetype)) {
+        entity.setLinetypeId(linetype);
+    }
+    if (isString(linetype)) {
+        entity.setLinetypeId(doc.getLinetypeId(linetype));
+    }
+    if (isNumber(lineweight)) {
+        entity.setLineweight(lineweight);
+    }
+
     return addEntity(entity);
 }
 
